@@ -14,7 +14,7 @@ def get_random_key(bytes: int) -> str:
     Returns
     -------
     str
-        Random key
+        Random key.
     """
 
     chars = "ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789.-_abcdefghijklmnopqrstuvwxyz"
@@ -56,4 +56,22 @@ def des_decrypt(encrypted : str):
     encrypted_text, key = encrypted.split("@")
     cipher = DES3.new(key.encode("ascii"), DES3.MODE_ECB)
     decrypted = cipher.decrypt(bytes.fromhex(encrypted_text))
-    return Padding.unpad(decrypted, 8).decode("utf8")
\ No newline at end of file
+    return Padding.unpad(decrypted, 8).decode("utf8")
+
+def roc_year_to_wastern(date_text : str) -> str:
+    """Convert ROC year to wastern year.
+
+    Parameters
+    ----------
+    date_text : str
+        `yyy...`.
+
+    Returns
+    -------
+    str
+        `yyyy...`
+    """
+
+    assert len(date_text) >= 7, "The `date_text` should be in `yyy...` format."
+
+    return f"{ str( 1911 + int(date_text[0:3])) }{date_text[3:]}"
\ No newline at end of file
